#!/bin/bash
# Author : Guth (guth@ploposor.com)
# URL : http://downloads.sourceforge.net/fwbuilder/fwbuilder-3.0.1.tar.gz

# program name/version
FilenameFromUrl="$(grep 'U[R]L' $0 | rev | cut -d '/' -f1 | rev)"
softname="$(echo $FilenameFromUrl | cut -d '-' -f1)"
softversion="$(echo $FilenameFromUrl | cut -d '-' -f2 | cut -d '.' -f -3)"
#softversion='1.1.4'
#softname='bchunk'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='54.1'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"
srcpkg="$buildir/$FilenameFromUrl"

if ! [ -f "$FilenameFromUrl" ]; then
    echo "Downloading the program tarball...$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)"
    wget "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" ||exit 0
fi


# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest ||exit 0
rm -f $package.* ||exit 0
mkdir -p $dest/usr/{bin,share/applications} ||exit 0
mkdir -p $dest/install ||exit 0
mkdir -p $dest/usr/src/$softname-$softversion ||exit 0
#mkdir -p $dest/usr/doc/$softname-$softversion ||exit 0

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
         |-----handy-ruler---------------------------------------------------|
$softname: $softname (Firewall creation utility)
$softname:
$softname: Firewall Builder is a GUI firewall configuration and management
$softname: tool that supports iptables (netfilter), ipfilter, pf, ipfw, Cisco
$softname: PIX (FWSM, ASA) and Cisco routers extended access lists. Firewall
$softname: Builder uses object-oriented approach, it helps administrator 
$softname: maintain a database of network objects and allows policy editing
$softname: using simple drag-and-drop operations.
$softname:
$softname:
$softname:
EOF


cat <<EOF > $dest/install/doinst.sh
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi
EOF

cat <<EOF > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Categories=System;
Comment=Design IPTables Firewall Rules
Encoding=UTF-8
Name=Firewall Builder
Icon=fwbuilder
Exec=fwbuilder
Type=Application
StartupNotify=true
Terminal=false
EOF

# extract sources
echo "extracting ..."
srcdir="$softname-$softversion"
cd $buildir ||exit 0
rm -rf $srcdir ||exit 0
tar zxf $srcdir.tar.gz ||exit 0
cd $srcdir ||exit 0

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

./configure \
   --prefix=/usr \
   --sysconfdir=/etc \
   --localstatedir=/var \
   --mandir=/usr/man

# compile package
make $ntasks ||exit 0

# install package to the target directory
INSTALL_ROOT=$dest make install DESTDIR=$dest ||exit 0

# copy the doc files
#cp -a \
# VERSION doc/{AUTHORS,COPYING,ChangeLog,Credits,*.txt,README*,examples.fwb} \
# $dest/usr/doc/$softname-$softversion ||exit 0

mv $dest/usr/share/{man,doc} $dest/usr/ ||exit 0

# strip executables
echo "stripping ..."
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# gzip man pages and info files
echo "gzipping ..."
gzip -9 $dest/usr/man/*/*
chown -R root.root $dest/usr/man/*/*


# put the ZenWalk build and other needed files in the right directory
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion ||exit 0
chown -R root.root $dest/usr/src/$softname-$softversion ||exit 0

# change files ownerships for $dest/usr/sbin
chown -R root.root $dest/usr/bin ||exit 0

# make the package and move it to the build directory

#------------------( Create The *.dep File )
echo "creating .dep ..."
cd $dest
requiredbuilder -z $dest > $buildir/$package.dep ||exit 0
#echo -n "" > $buildir/$package.dep ||exit 0

cd $dest
/sbin/makepkg -l y -c n $package.tgz ||exit 0
mv $package.tgz $buildir ||exit 0

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir ||exit 0
md5sum $package.tgz > $package.md5 ||exit 0

echo "glibc" > $package.dep

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

echo "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" > $package.src
echo "http://zen-repo.meticul.eu/zen_stuffs/guth/packages/$softname/build-$softname.sh" >> $package.src
